Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--source/blender/sequencer/intern/render.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/sequencer/intern/render.c b/source/blender/sequencer/intern/render.c
index 8d6a61f3c5d..cd993ae45c1 100644
--- a/source/blender/sequencer/intern/render.c
+++ b/source/blender/sequencer/intern/render.c
@@ -728,12 +728,12 @@ static ImBuf *seq_render_preprocess_ibuf(const SeqRenderData *context,
use_preprocess = true;
}
- if (use_preprocess) {
- /* Proxies are not stored in cache. */
- if (!is_proxy_image) {
- seq_cache_put(context, seq, timeline_frame, SEQ_CACHE_STORE_RAW, ibuf, false);
- }
+ /* Proxies and effect strips are not stored in cache. */
+ if (!is_proxy_image && (seq->type & SEQ_TYPE_EFFECT) == 0) {
+ seq_cache_put(context, seq, timeline_frame, SEQ_CACHE_STORE_RAW, ibuf, false);
+ }
+ if (use_preprocess) {
ibuf = input_preprocess(context, seq, timeline_frame, ibuf);
}